import rich_click as click

click.rich_click.SHOW_METAVARS_COLUMN = False
click.rich_click.APPEND_METAVARS_HELP = True


@click.command()
@click.option("--debug", is_flag=True, help="Enable debug mode.")
@click.option(
    "--number",
    type=click.Choice(
        [
            "one",
            "two",
            "three",
            "four",
            "five",
            "six",
            "seven",
            "eight",
            "nine",
            "ten",
            "eleven",
            "twelve",
            "thirteen",
            "fourteen",
            "fifteen",
            "sixteen",
            "seventeen",
            "eighteen",
            "nineteen",
            "twenty",
            "twenty-one",
            "twenty-two",
            "twenty-three",
            "twenty-four",
            "twenty-five",
            "twenty-six",
            "twenty-seven",
            "twenty-eight",
            "twenty-nine",
            "thirty",
        ]
    ),
    show_default=True,
    help="This click choice has loads of options.",
)
def cli(debug, number):
    """
    My amazing tool does all the things.

    This is a minimal example based on documentation
    from the 'click' package.

    You can try using --help at the top level and also for
    specific group subcommands.
    """
    print(f"Debug mode is {'on' if debug else 'off'}")


if __name__ == "__main__":
    cli()



import rich_click as click

# Show custom error messages
click.rich_click.STYLE_ERRORS_SUGGESTION = "magenta italic"
click.rich_click.ERRORS_SUGGESTION = "Try running the '--help' flag for more information."
click.rich_click.ERRORS_EPILOGUE = "To find out more, visit [link=https://mytool.com]https://mytool.com[/link]"


@click.command()
@click.argument("input", type=click.Path(), required=True)
@click.option(
    "--type",
    default="files",
    show_default=True,
    help="Type of file to sync",
)
@click.option("--all", is_flag=True, help="Sync all the things?")
@click.option("--debug", is_flag=True, default=False, help="Enable debug mode")
def cli(input, type, all, debug):
    """
    My amazing tool does all the things.

    This is a minimal example based on documentation
    from the 'click' package.

    You can try using --help at the top level and also for
    specific group subcommands.
    """
    print(f"Debug mode is {'on' if debug else 'off'}")


if __name__ == "__main__":
    cli()



import click

from rich_click import RichCommand, RichGroup


@click.group(cls=RichGroup)
@click.option("--debug/--no-debug", default=False)
def cli(debug):
    """
    My amazing tool does all the things.

    This is a minimal example based on documentation
    from the 'click' package.

    You can try using --help at the top level and also for
    specific group subcommands.
    """
    click.echo(f"Debug mode is {'on' if debug else 'off'}")


@cli.command(cls=RichCommand)
def sync():
    """Synchronise all your files between two places."""
    click.echo("Syncing")


if __name__ == "__main__":
    cli()



import rich_click as click

# Use Markdown (bit of a ridiculous example!)
click.rich_click.USE_MARKDOWN = True


@click.command()
@click.option(
    "--input",
    type=click.Path(),
    help="Input **file**. _[default: a custom default]_",
)
@click.option(
    "--type",
    default="files",
    show_default=True,
    help="Type of file to sync",
)
@click.option("--all", is_flag=True, help="Sync\n 1. all\n 2. the\n 3. things?")
@click.option("--debug", is_flag=True, help="# Enable `debug mode`")
def cli(input, type, all, debug):
    """
    My amazing tool does _**all the things**_.

    This is a `minimal example` based on documentation from the [_click_ package](https://click.palletsprojects.com/).

    > Remember:
    >  - You can try using --help at the top level
    >  - Also for specific group subcommands.

    """
    print(f"Debug mode is {'on' if debug else 'off'}")


if __name__ == "__main__":
    cli()



import rich_click as click


@click.group()
@click.option(
    "--debug/--no-debug",
    "-d/-n",
    default=False,
    help="""Enable debug mode.
    Newlines are removed by default.

    Double newlines are preserved.""",
)
def cli(debug):
    """
    My amazing tool does all the things.

    This is a minimal example based on documentation
    from the 'click' package.

    You can try using --help at the top level and also for
    specific subcommands.
    """
    print(f"Debug mode is {'on' if debug else 'off'}")


@cli.command()
@click.option(
    "--type",
    required=True,
    default="files",
    show_default=True,
    help="Type of file to sync",
)
@click.option("--all", is_flag=True)
def sync(type, all):
    """Synchronise all your files between two places.
    Example command that doesn't do much except print to the terminal."""
    print("Syncing")


@cli.command(short_help="Optionally use short-help for the group help text")
@click.option("--all", is_flag=True, help="Get everything")
def download(all):
    """
    Pretend to download some files from
    somewhere. Multi-line help strings are unwrapped
    until you use a double newline.

    Only the first paragraph is used in group help texts.
    Don't forget you can opt-in to rich and markdown formatting!

    \b
    Click escape markers should still work.
      * So you
      * Can keep
      * Your newlines

    And this is a paragraph
    that will be rewrapped again.

    \f
    Also if you want to write function help text that won't
    be rendered to the terminal.
    """
    print("Downloading")


if __name__ == "__main__":
    cli()



import rich_click as click

# import click

# Example test usage:
# GREETER_DEBUG=1 GREETER_GREET_USERNAME="test" EMAIL_ADDRESS="foo@bar.com" python examples/09_envvar.py greet


@click.group()
@click.option("--debug/--no-debug")
def cli(debug):
    click.echo(f"Debug mode is {'on' if debug else 'off'}")


@cli.command()
@click.option("--username", help="This can be set via env var GREETER_GREET_USERNAME", show_envvar=True)
@click.option(
    "--nickname",
    envvar="NICKNAME",
    show_envvar=True,
    show_default=True,
    help="This can be set via env var NICKNAME",
)
@click.option(
    "--email",
    envvar=["EMAIL", "EMAIL_ADDRESS"],
    show_envvar=True,
    default="foo@bar.com",
    show_default=True,
    help="This can be set via env var EMAIL or EMAIL_ADDRESS",
)
def greet(username, nickname, email):
    click.echo(f"Hello {username} ({nickname}) with email {email}!")


if __name__ == "__main__":
    cli(auto_envvar_prefix="GREETER")



import rich_click as click

click.rich_click.STYLE_OPTIONS_TABLE_LEADING = 1
click.rich_click.STYLE_OPTIONS_TABLE_BOX = "SIMPLE"
click.rich_click.STYLE_OPTIONS_TABLE_ROW_STYLES = ["bold", ""]
click.rich_click.STYLE_COMMANDS_TABLE_SHOW_LINES = True
click.rich_click.STYLE_COMMANDS_TABLE_PAD_EDGE = True
click.rich_click.STYLE_COMMANDS_TABLE_BOX = "DOUBLE"
click.rich_click.STYLE_COMMANDS_TABLE_BORDER_STYLE = "red"
click.rich_click.STYLE_COMMANDS_TABLE_ROW_STYLES = ["magenta", "yellow", "cyan", "green"]


@click.group()
@click.option(
    "--type",
    default="files",
    help="""
    Type of file to sync.
    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
    Sed sed mauris euismod, semper leo quis, sodales augue.
    Donec posuere nulla quis egestas ornare.
    Nam efficitur ex quis diam tempus, nec euismod diam consectetur.
    Etiam vitae nisi at odio hendrerit dictum in at dui.
    Aliquam nulla lacus, pellentesque id ultricies sit amet, mollis nec tellus.
    Aenean arcu justo, pellentesque viverra justo eget, tempus tincidunt lectus.
    Maecenas porttitor risus vitae libero dapibus ullamcorper.
    Cras faucibus euismod erat in porta.
    Phasellus cursus gravida ante vel aliquet.
    In accumsan enim nec ullamcorper gravida.
    Donec malesuada dui ac metus tristique cursus.
    Sed gravida condimentum fermentum.
    Ut sit amet nulla commodo, iaculis tellus vitae, accumsan enim.
    Curabitur mollis semper velit a suscipit.
    """,
)
@click.option(
    "--debug/--no-debug",
    "-d/-n",
    default=False,
    help="""
    Show the debug log messages.
    Suspendisse dictum hendrerit turpis eu rutrum.
    Vivamus magna ex, elementum sit amet sapien laoreet, tempor consequat eros.
    Morbi semper feugiat nisi eget sodales.
    Pellentesque et turpis erat.
    Donec ac aliquam risus.
    Nam leo tellus, rutrum et scelerisque vitae, ultrices sed metus.
    Ut sollicitudin convallis turpis, sit amet sollicitudin felis semper feugiat.
    In sapien dui, aliquam eget dui quis, auctor maximus nibh.
    Suspendisse maximus sem arcu.
    Pellentesque sit amet semper est.
    Cras pulvinar ut tellus a semper.
    In facilisis tellus odio, non porta nisl accumsan nec.
    Pellentesque sollicitudin quam ac felis congue, ac congue enim tempor.
    """,
)
@click.version_option("1.23", prog_name="mytool")
def cli(type, debug):
    """
    My amazing tool does all the things.

    This is a minimal example based on documentation
    from the 'click' package.

    You can try using --help at the top level and also for
    specific group subcommands.
    """
    print(f"Debug mode is {'on' if debug else 'off'}")


@cli.command()
@click.option("--input", "-i", required=True, help="Input path")
@click.option("--output", "-o", help="Output path")
@click.option("--all", is_flag=True, help="Sync all the things?")
@click.option("--overwrite", is_flag=True, help="Overwrite local files")
def sync(input, output, all, overwrite):
    """
    Synchronise all your files between two places.
    Curabitur congue eget lorem in lacinia.
    Praesent tempus nunc nec nulla dignissim, et lacinia ipsum accumsan.
    Duis sodales, sapien at fermentum condimentum, diam metus porttitor lacus, nec gravida mi diam eget ligula.
    Pellentesque elementum at justo a luctus.
    Mauris a interdum odio.
    Maecenas in consectetur velit.
    Ut tristique congue felis at tempus.
    Donec pulvinar tortor ut odio posuere imperdiet.
    Fusce lacinia iaculis diam in scelerisque.
    Pellentesque in lorem est.
    Nulla efficitur luctus lacus, auctor auctor dui hendrerit a.
    Ut nec iaculis dolor.
    Morbi metus lectus, aliquet et sapien nec, congue euismod lorem.
    Pellentesque tristique tempus augue at convallis.
    """
    print("Syncing")


@cli.command()
@click.option("--all", is_flag=True, help="Get everything")
def download(all):
    """
    Pretend to download some files from somewhere.
    Integer bibendum libero nunc, sed aliquet ex tincidunt vel.
    Duis vitae sem vel odio luctus suscipit nec vitae enim.
    Curabitur vel lectus nec quam maximus dapibus.
    Phasellus eros velit, maximus non hendrerit nec, tempor fringilla urna.
    Vivamus vel nibh quis sapien consectetur fermentum.
    Curabitur at ultrices quam, vel molestie justo.
    Nunc lobortis orci vel nibh sagittis pretium.
    Morbi rhoncus sapien luctus, ultrices urna vel, convallis tortor.
    """
    print("Downloading")


@cli.command()
def auth():
    """
    Authenticate the app.
    Duis lacus nibh, feugiat a nibh a, commodo dictum libero.
    Ut ac nulla tincidunt, bibendum nisi vitae, sodales ex.
    Vestibulum efficitur, lectus quis venenatis porta, dolor elit varius mauris, consequat interdum lectus est quis mi.
    Vestibulum imperdiet sed dolor eget semper.
    Cras ut mauris ac libero hendrerit congue.
    Vivamus pretium nunc turpis, eget imperdiet sapien tempor auctor.
    Phasellus risus nisi, laoreet in posuere sit amet, sodales non diam.
    Aliquam non malesuada urna, a faucibus risus.
    """
    print("Downloading")


@cli.command()
def config():
    """
    Set up the configuration.
    Sed accumsan ornare odio dictum aliquam.
    Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.
    Curabitur in pellentesque mauris.
    Nulla mollis dui finibus, dictum neque id, suscipit nisl.
    Nunc mauris ex, laoreet nec tincidunt ut, pellentesque ut tortor.
    Mauris fermentum diam at porttitor tempor.
    Aliquam euismod nisi massa, nec placerat ante euismod quis.
    """
    print("Downloading")


if __name__ == "__main__":
    cli()



import rich_click as click

click.rich_click.OPTION_GROUPS = {
    "03_groups_sorting.py": [
        {
            "name": "Basic usage",
            "options": ["--type", "--output"],
        },
        {
            "name": "Advanced options",
            "options": ["--help", "--version", "--debug"],
            # You can also set table styles at group-level instead of using globals if you want
            "table_styles": {
                "row_styles": ["bold", "yellow", "cyan"],
            },
        },
    ],
    "03_groups_sorting.py sync": [
        {
            "name": "Inputs and outputs",
            "options": ["--input", "--output"],
        },
        {
            "name": "Advanced usage",
            "options": ["--overwrite", "--all", "--help"],
        },
    ],
}
click.rich_click.COMMAND_GROUPS = {
    "03_groups_sorting.py": [
        {
            "name": "Main usage",
            "commands": ["sync", "download"],
        },
        {
            "name": "Configuration",
            "commands": ["config", "auth"],
        },
    ]
}


@click.group(context_settings=dict(help_option_names=["-h", "--help"]))
@click.option(
    "--type",
    default="files",
    show_default=True,
    required=True,
    help="Type of file to sync",
)
@click.option(
    "--debug/--no-debug",
    "-d/-n",
    default=False,
    show_default=True,
    help="Show the debug log messages",
)
@click.version_option("1.23", prog_name="mytool")
def cli(type, debug):
    """
    My amazing tool does all the things.

    This is a minimal example based on documentation
    from the 'click' package.

    You can try using --help at the top level and also for
    specific subcommands.
    """
    print(f"Debug mode is {'on' if debug else 'off'}")


@cli.command()
@click.option("--input", "-i", required=True, help="Input path")
@click.option("--output", "-o", help="Output path")
@click.option("--all", is_flag=True, help="Sync all the things?")
@click.option("--overwrite", is_flag=True, help="Overwrite local files")
def sync(input, output, all, overwrite):
    """Synchronise all your files between two places."""
    print("Syncing")


@cli.command()
@click.option("--all", is_flag=True, help="Get everything")
def download(all):
    """Pretend to download some files from somewhere."""
    print("Downloading")


@cli.command()
def auth():
    """Authenticate the app."""
    print("Downloading")


@cli.command()
def config():
    """Set up the configuration."""
    print("Downloading")


if __name__ == "__main__":
    cli()



import rich_click as click

# Use Rich markup
click.rich_click.USE_RICH_MARKUP = True


@click.command()
@click.option(
    "--input",
    type=click.Path(),
    help="Input [magenta bold]file[/]. [dim]\[default: a custom default][/]",
)
@click.option(
    "--type",
    default="files",
    show_default=True,
    help="Type of file to sync",
)
@click.option("--all", is_flag=True, help="Sync all the things?")
@click.option("--debug", is_flag=True, help="Enable :point_right: [yellow]debug mode[/] :point_left:")
def cli(input, type, all, debug):
    """
    My amazing tool does [black on blue] all the things [/].

    This is a [u]minimal example[/] based on documentation
    from the [link=https://click.palletsprojects.com/]'click' package[/].

    [i]You can try using --help at the top level and also for
    specific group subcommands.[/]
    """
    print(f"Debug mode is {'on' if debug else 'off'}")


if __name__ == "__main__":
    cli()
